@@ -1,7 +1,7 @@
 import cv2
 import matplotlib.pyplot as plt
 import numpy as np
-from utils import geometry, interpolate, spline_geometry, resample
+from .utils import geometry, interpolate, spline_geometry, resample
 
 
 class Straightener(object):
